@@ -1,7 +1,5 @@
 package Perl6::Pod::Block::comment;
 
-#$Id$
-
 =pod
 
 =head1 NAME
@@ -23,10 +21,6 @@ use strict;
 use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
 
-sub start {
-    my $self = shift;
-    $self->delete_element->skip_content;
-}
 
 1;
 
@@ -45,7 +39,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009-2012 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
