@@ -72,33 +72,6 @@ use Test::More;
 use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
 
-sub on_para {
-    my $self   = shift;
-    my $parser = shift;
-    my $txt    = shift;
-    return unless defined $txt;
-    my $line_num = $self->context->custom->{_line_num_};
-
-    # convert paragrapths to para
-    # skip tag
-    for ( split( /[\n\r]\s*[\n\r]/, $txt ) ) {
-
-       # check if block code
-       #detect type of para
-       #from S26
-       #A code block may be implicitly specified as one or more lines of text,
-       #each of which starts with a whitespace character at the block's virtual
-       #left margin. The implicit code block is then terminated by a blank line.
-        my $lines                 = scalar @{ [m/^/mg] };
-        my $lines_with_whitespace = scalar @{ [m/^(\s+)\S+/mg] };
-        my $block_type = ( $lines == $lines_with_whitespace ) ? 'code' : 'para';
-        $parser->start_block( $block_type, '', $line_num );
-        $parser->para($_);
-        $parser->end_block( $block_type, '', $line_num );
-    }
-    return;
-}
-
 =head2 to_xhtml
 
     =nested
@@ -112,12 +85,10 @@ Render to:
 =cut
 
 sub to_xhtml {
-    my $self   = shift;
-    my $parser = shift;
-    my $el =
-      $parser->mk_element('blockquote')
-      ->add_content( $parser->_make_elements(@_) );
-    return $el;
+    my ( $self, $to ) = @_;
+    $to->w->start_nesting();
+    $to->visit_childs($self);
+    $to->w->stop_nesting();
 }
 
 =head2 to_docbook
@@ -133,12 +104,10 @@ Render to:
 =cut
 
 sub to_docbook {
-    my $self   = shift;
-    my $parser = shift;
-    my $el =
-      $parser->mk_element('blockquote')
-      ->add_content( $parser->_make_elements(@_) );
-    return $el;
+    my ( $self, $to ) = @_;
+    $to->w->start_nesting();
+    $to->visit_childs($self);
+    $to->w->stop_nesting();
 }
 1;
 __END__
