@@ -58,7 +58,8 @@ qr{
                                                  &&
                                         ( $MATCH ne lc($MATCH) )  })>
     <rule: raw_content> 
-                        .*?
+                        (?:(?!^<spaces=hs>?=\w+).)*   # match everythig, except
+                                                      # it looks like directive
                     (?{ $MATCH{type} = "raw"})
 
     <rule: block_content> 
